#include <vector>
#include <cstddef>
#include <iostream>
#include <cmath>
#include <algorithm>
#include <array>

using Timestamp = std::uint32_t;

using Timestamps = std::vector<Timestamp>;

struct Info {
	std::size_t max_index;
	Timestamp min_delta;

	static Info find(Timestamps const& timestamps) noexcept
	{
		Timestamp max_delta = timestamps[1] - timestamps[0];
		Timestamp min_delta = max_delta;
		std::size_t max_index = 0;

		for (std::size_t i = 1; i < timestamps.size() - 1; ++i)
		{
			Timestamp delta = timestamps[i + 1] - timestamps[i];
			if (delta > max_delta)
			{
				max_index = i;
				max_delta = delta;
			}
			else if (delta < min_delta)
			{
				min_delta = delta;
			}
		}

		return {
			max_index,
			min_delta
		};
	}
};

struct Solution {
	std::size_t index;
	Timestamp timestamp;

	static Solution find(Timestamps const& timestamps) noexcept
	{
		if (timestamps.size() == 2)
		{
			return {
				0,
				timestamps[1]
			};
		}

		auto info = Info::find(timestamps);

		// 1 choice
		if (info.max_index == 0)
		{
			return {
				info.max_index,
				timestamps[info.max_index + 1] - info.min_delta
			};
		}
		
		// 3 choices
		// Move current to next
		auto current_to_next_timestamp = timestamps[info.max_index + 1] - info.min_delta;
		auto current_to_next_rating = current_to_next_timestamp - timestamps[info.max_index - 1];

		// Move next to current
		auto next_to_current_timestamp = timestamps[info.max_index] + info.min_delta;
		auto next_to_current_rating = (info.max_index + 2 == timestamps.size()) ? 0 : timestamps[info.max_index + 2] - next_to_current_timestamp;

		// Move current evenly
		Timestamp current_even_timestamp = (timestamps[info.max_index - 1] + timestamps[info.max_index + 1]) / 2;
		auto current_even_rating = timestamps[info.max_index + 1] - current_even_timestamp;

		// Move next evenly
		Timestamp next_even_timestamp;
		Timestamp next_even_rating;
		if (info.max_index + 2 == timestamps.size())
		{
			next_even_timestamp = 0;
			next_even_rating = std::numeric_limits<Timestamp>::max();
		}
		else
		{
			next_even_timestamp = (timestamps[info.max_index] + timestamps[info.max_index + 2]) / 2;
			next_even_rating = next_even_timestamp - timestamps[info.max_index];
		}

		// Use that which has minimum rating
		std::array<Timestamp, 4> const ratings {{ current_to_next_rating, next_to_current_rating, current_even_rating, next_even_rating }};
		auto const min_rating = *std::min_element(ratings.cbegin(), ratings.cend());

		if (min_rating == current_to_next_rating)
		{ // Move current to next
			return {
				info.max_index, current_to_next_timestamp
			};
		}

		if (min_rating == next_to_current_rating)
		{ // Move next to current
			return {
				info.max_index + 1, next_to_current_timestamp
			};
		}

		if (min_rating == current_even_rating)
		{
			return {
				info.max_index, current_even_timestamp
			};
		}

		// min_rating == next_even_rating
		return {
			info.max_index + 1, next_even_timestamp
		};
	}
};

int main()
{
	std::ios::sync_with_stdio(false);
	std::cin.tie(0);

	std::size_t num_timestamps;
	std::cin >> num_timestamps;

	Timestamps timestamps(num_timestamps);
	for (std::size_t i = 0; i < num_timestamps; ++i)
		std::cin >> timestamps[i];

	auto solution = Solution::find(timestamps);
	std::cout << (solution.index + 1) << ' ' << solution.timestamp << '\n';
}

